@@ -26,8 +26,6 @@ import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.avalon.framework.configuration.Configuration;
-
 import org.apache.xmlgraphics.image.loader.ImageContext;
 import org.apache.xmlgraphics.image.loader.ImageManager;
 import org.apache.xmlgraphics.image.loader.impl.AbstractImageSessionContext.FallbackResolver;
@@ -35,6 +33,7 @@ import org.apache.xmlgraphics.io.ResourceResolver;
 
 import org.apache.fop.apps.io.InternalResourceResolver;
 import org.apache.fop.apps.io.ResourceResolverFactory;
+import org.apache.fop.configuration.Configuration;
 import org.apache.fop.fonts.FontManager;
 import org.apache.fop.layoutmgr.LayoutManagerMaker;
 
@@ -161,6 +160,11 @@ public final class FopFactoryBuilder {
         return this;
     }
 
+    public FopFactoryBuilder setKeepEmptyTags(boolean b) {
+        fopFactoryConfigBuilder.setKeepEmptyTags(b);
+        return this;
+    }
+
     /**
      * Sets the {@link LayoutManagerMaker} so that users can configure how FOP creates
      * {@link org.apache.fop.layoutmgr.LayoutManager}s.
@@ -331,6 +335,8 @@ public final class FopFactoryBuilder {
 
         private boolean accessibility;
 
+        private boolean keepEmptyTags = true;
+
         private LayoutManagerMaker layoutManagerMaker;
 
         private URI baseURI;
@@ -386,6 +392,10 @@ public final class FopFactoryBuilder {
             return accessibility;
         }
 
+        public boolean isKeepEmptyTags() {
+            return keepEmptyTags;
+        }
+
         /** {@inheritDoc} */
         public LayoutManagerMaker getLayoutManagerMakerOverride() {
             return layoutManagerMaker;
@@ -486,6 +496,7 @@ public final class FopFactoryBuilder {
     private interface FopFactoryConfigBuilder {
 
         void setAccessibility(boolean enableAccessibility);
+        void setKeepEmptyTags(boolean b);
 
         void setLayoutManagerMakerOverride(LayoutManagerMaker lmMaker);
 
@@ -532,6 +543,9 @@ public final class FopFactoryBuilder {
         public void setAccessibility(boolean enableAccessibility) {
             throwIllegalStateException();
         }
+        public void setKeepEmptyTags(boolean b) {
+            throwIllegalStateException();
+        }
 
         public void setLayoutManagerMakerOverride(LayoutManagerMaker lmMaker) {
             throwIllegalStateException();
@@ -613,6 +627,10 @@ public final class FopFactoryBuilder {
             config.accessibility = enableAccessibility;
         }
 
+        public void setKeepEmptyTags(boolean b) {
+            config.keepEmptyTags = b;
+        }
+
         public void setLayoutManagerMakerOverride(LayoutManagerMaker lmMaker) {
             config.layoutManagerMaker = lmMaker;
         }
